Estimate a population model and generate a synthetic dataset from it
Source:R/model-estimate.R
synpmx_model.RdA single call for synpmx_model_estimate() followed by
synpmx_model_generate(). Use the two separately to look at the fit before
generating from it; it is on the result either way, as the pmx_fitted_model
attribute.
Arguments
- data
Source PMX event data.
- roles
Explicit column roles from
pmx_roles(), includingnominal_time.- n_subjects
Number of synthetic subjects. Defaults to the source count.
- seed
Seed, used for both stages.
- ...
Passed to
synpmx_model_estimate().